@@ -87,7 +87,10 @@ def _open_file(path: str) -> Optional[io.TextIOWrapper]:
     if path.startswith("/"):
         filepath = path
     else:
-        filepath = os.path.expanduser("~/" + path)
+        if "PSQUARED_HOME" in os.environ:
+            filepath = os.environ["PSQUARED_HOME"] + os.sep + path
+        else:
+            filepath = os.path.expanduser("~/" + path)
     directory = os.path.dirname(filepath)
     if None is not directory and "" != directory:
         _mkdirs(directory)
